@@ -4,14 +4,15 @@ import os
 from datetime import datetime
 from typing import List, Union, Set, Dict
 from urllib.parse import urljoin
+
 import requests
 from bs4 import BeautifulSoup
 from dotenv import load_dotenv
 from ruamel.yaml import YAML
 
 from teko.helpers.clog import CLog
-from teko.helpers.exceptions import raise_jira_exception
-from teko.models.jira_testcase import JiraTestData
+from teko.helpers.exceptions import TekoJiraException, raise_jira_exception
+from teko.models.jira_tool.jira_testcase import JiraTestData
 
 
 def quoted_testcase_name(name: str):
@@ -23,6 +24,7 @@ class JiraService:
     """
     Jira API docs: https://support.smartbear.com/zephyr-scale-server/api-docs/v1/
     """
+
     def __init__(self, config={}):
         """
 
@@ -199,7 +201,8 @@ class JiraService:
             if res.status_code == 401:
                 CLog.error(f"Unauthorized: Authenticated failed.")
             elif res.status_code == 403:
-                CLog.error(f"Forbidden: You don't have permission to send request POST to {url} with payload {confluences_data}.")
+                CLog.error(
+                    f"Forbidden: You don't have permission to send request POST to {url} with payload {confluences_data}.")
             elif not res.text:
                 CLog.error(f"HTTP Error {res.status_code}. No response message.")
             else:
@@ -237,7 +240,8 @@ class JiraService:
             if res.status_code == 401:
                 CLog.error(f"Unauthorized: Authenticated failed.")
             elif res.status_code == 403:
-                CLog.error(f"Forbidden: You don't have permission to send request POST to {url} with payload {webs_data}.")
+                CLog.error(
+                    f"Forbidden: You don't have permission to send request POST to {url} with payload {webs_data}.")
             elif not res.text:
                 CLog.error(f"HTTP Error {res.status_code}. No response message.")
             else:
@@ -544,7 +548,8 @@ class JiraService:
                 if res.status_code == 401:
                     CLog.error(f"Unauthorized: Authenticated failed.")
                 elif res.status_code == 403:
-                    CLog.error(f"Forbidden: You don't have permission to send request POST to {url} with payload {data}.")
+                    CLog.error(
+                        f"Forbidden: You don't have permission to send request POST to {url} with payload {data}.")
                 elif not res.text:
                     CLog.error(f"HTTP Error {res.status_code}. No response message.")
                 else:
@@ -634,7 +639,7 @@ class JiraService:
                 yaml.indent(offset=2)
                 yaml.dump(testcases_json, f)
         else:
-            raise_jira_exception(f"File format not supported: {ext}.")
+            raise TekoJiraException(f"File format not supported: {ext}.")
 
 
 if __name__ == "__main__":
@@ -647,6 +652,3 @@ if __name__ == "__main__":
     testcycle_file = "../../../sample/testcycles.yaml"
     testcases = JiraService.read_test_from_file(testcycle_file)
     jira_srv.create_test_cycles(testcases)
-
-
-
